@@ -23,6 +23,7 @@ from antgo.measures.statistic import *
 from antgo.measures.repeat_statistic import *
 from antgo.measures.deep_analysis import *
 import signal
+import traceback
 if sys.version > '3':
     PY3 = True
 else:
@@ -424,6 +425,13 @@ class AntTrain(AntBase):
                                                  os.path.join(self.ant_data_source, running_ant_task.dataset_name),
                                                  running_ant_task.dataset_params)
 
+    # 5.1.step 检查设置候选数据
+    if self.context.params.system['candidate']:
+      print('HERE')
+      ant_train_dataset = CandidateDataset(ant_train_dataset)
+      if ant_train_dataset is None:
+        print('why here')
+      
     # 6.step 消除实验
     # if ablation_blocks is not None:
     #   if len(apply_devices) >= ablation_experiments_devices_num + 1:
@@ -673,6 +681,7 @@ class AntTrain(AntBase):
       except Exception as e:
         if type(e.__cause__) != StopIteration:
           print(e)
+          traceback.print_exc()
       
       self.context.from_experiment = train_dump_dir
       logger.info('Stop training process.')
@@ -698,6 +707,7 @@ class AntTrain(AntBase):
       except Exception as e:
           if type(e.__cause__) != StopIteration:
             print(e)
+            traceback.print_exc()
 
       self.context.from_experiment = dump_dir
     
@@ -714,6 +724,7 @@ class AntTrain(AntBase):
         except Exception as e:
           if type(e.__cause__) != StopIteration:
             print(e)
+            traceback.print_exc()
 
     task_running_statictic = get_performance_statistic(self.ant_name)
     task_running_statictic = {self.ant_name: task_running_statictic}
@@ -817,6 +828,7 @@ class AntTrain(AntBase):
       except Exception as e:
           if type(e.__cause__) != StopIteration:
             print(e)
+            traceback.print_exc()
 
       self.context.from_experiment = dump_dir
       logger.info('Stop training process at repeathold %d round.' % repeat)
@@ -836,6 +848,7 @@ class AntTrain(AntBase):
           except Exception as e:
             if type(e.__cause__) != StopIteration:
               print(e)
+              traceback.print_exc()
 
       logger.info('Start infer process at repeathold %d round.' % repeat)
       
@@ -896,6 +909,7 @@ class AntTrain(AntBase):
       except Exception as e:
           if type(e.__cause__) != StopIteration:
             print(e)
+            traceback.print_exc()
 
       self.context.from_experiment = dump_dir
       logger.info('Stop training process at bootstrap %d round.' % bootstrap_i)
@@ -914,6 +928,7 @@ class AntTrain(AntBase):
           except Exception as e:
             if type(e.__cause__) != StopIteration:
               print(e)
+              traceback.print_exc()
 
       logger.info('Stop infer process at bootstrap %d round.' % bootstrap_i)
       
@@ -974,6 +989,7 @@ class AntTrain(AntBase):
       except Exception as e:
           if type(e.__cause__) != StopIteration:
             print(e)
+            traceback.print_exc()
 
       self.context.from_experiment = dump_dir
       logger.info('Stop training process at kfold %d round.'%k)
@@ -993,6 +1009,7 @@ class AntTrain(AntBase):
           except Exception as e:
             if type(e.__cause__) != StopIteration:
               print(e)
+              traceback.print_exc()
 
       logger.info('Stop infer process at kfold %d round.'%k)
       # clear
