@@ -6,8 +6,9 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 import sys
-# sys.path.append('/workspace/workspace/portrait_code/tool/antgo')
-# sys.path.append('/workspace/workspace/portrait_code/tool/antgo/antgo')
+from typing import NamedTuple
+sys.path.append('/workspace/workspace/portrait_code/tool/antgo')
+sys.path.append('/workspace/workspace/portrait_code/tool/antgo/antgo')
 from antgo.ant.generate import *
 from antgo.ant.demo import *
 from antgo.ant.train import *
@@ -21,6 +22,7 @@ from antgo.sandbox.sandbox import *
 from antgo.utils.utils import *
 from antgo.utils.dht import *
 from antgo import version
+import traceback
 from jinja2 import Environment, FileSystemLoader
 
 import multiprocessing
@@ -82,7 +84,8 @@ flags.DEFINE_integer('host_port', -1, 'port')
 flags.DEFINE_string('html_template', None, 'html template')
 flags.DEFINE_indicator('worker', '')
 flags.DEFINE_indicator('master', '')
-flags.DEFINE_indicator('unlabel', '')
+flags.DEFINE_indicator('unlabel', '')           # 未标注数据
+flags.DEFINE_indicator('candidate', '')         # 候选数据
 flags.DEFINE_indicator('skip_training', '')
 flags.DEFINE_indicator('research', 'research mode or not')
 flags.DEFINE_string('running_platform', 'local', 'local/cloud')
@@ -110,17 +113,40 @@ def main():
     token = unicode(token)
 
   if sys.argv[1] == 'config':
+    if not os.path.exists(os.path.join(os.environ['HOME'], '.config', 'antgo')):
+      os.makedirs(os.path.join(os.environ['HOME'], '.config', 'antgo'))
+
     if FLAGS.config() is not None:
       # 使用指定配置文件更新
-      if not os.path.exists(os.path.join(os.environ['HOME'], '.config', 'antgo')):
-        os.makedirs(os.path.join(os.environ['HOME'], '.config', 'antgo'))
-
       shutil.copy(FLAGS.config(), os.path.join(os.environ['HOME'], '.config', 'antgo', 'config.xml'))
       logger.info('Success update config file.')
     else:
       # 在当前目录生成默认配置文件
-      shutil.copy(os.path.join('/'.join(os.path.realpath(__file__).split('/')[0:-1]), 'config.xml'), "./config.xml")
-      logger.info('Build default config file.')
+      # --dataset, --token, 自动配置
+      config_data = {'DATASET_FACTORY': '', 'USER_TOKEN': ''}
+      if FLAGS.dataset() is not None:
+        if not os.path.exists(FLAGS.dataset()):
+          logger.error('Dataset factory path dont exist.')
+          return
+        config_data['DATASET_FACTORY'] = FLAGS.dataset()
+
+      if FLAGS.token() is not None:
+         config_data['USER_TOKEN'] = FLAGS.token()
+
+      env = Environment(loader=FileSystemLoader('/'.join(os.path.realpath(__file__).split('/')[0:-1])))
+      config_template = env.get_template('config.xml')
+      config_content = config_template.render(**config_data)
+
+      if config_data['DATASET_FACTORY'] != '':
+        with open(os.path.join(os.environ['HOME'], '.config', 'antgo', 'config.xml'),'w') as fp:
+          fp.write(config_content)
+        
+        logger.info('Finish antgo global config.')
+      else:
+        with open('./config.xml','w') as fp:
+          fp.write(config_content)
+
+        logger.info('Please fill ./config.xml, then call (antgo config --config=./config.xml) to finish global config.')
     return
 
   # 检查配置文件是否存在
@@ -138,7 +164,7 @@ def main():
     sys_a, sys_b, sys_c = version.split('.')
     if int(sys_a) < int(a) or int(sys_b) < int(b) or int(sys_c) < int(c):
       logger.error('Antgo version dont satisfy task minimum request (%s).'%FLAGS.version())
-      sys.exit(-1)
+      return
 
   # 4.step check factory
   factory = getattr(Config, 'factory', None)
@@ -265,7 +291,7 @@ def main():
   if main_file is None or not os.path.exists(os.path.join(main_folder, main_file)):
     if not (FLAGS.worker() or FLAGS.master()):
       logger.error('Main executing file dont exist.')
-      sys.exit(-1)
+      return
 
   # 8 step ant running
   # 8.1 step what is task
@@ -287,7 +313,7 @@ def main():
                      '<estimation_procedure><type>%s</type></estimation_procedure>' \
                      '<evaluation_measures><evaluation_measure>%s</evaluation_measure></evaluation_measures>' \
                      '</input>' \
-                     '</task>'%('default-task', FLAGS.task_t(), FLAGS.task_badcase_num(), FLAGS.task_badcase_category(),dataset, FLAGS.task_ep(), FLAGS.task_em())
+                     '</task>'%(name, FLAGS.task_t(), FLAGS.task_badcase_num(), FLAGS.task_badcase_category(), dataset, FLAGS.task_ep(), FLAGS.task_em())
       fp.write(task_content)
     task = os.path.join(task_factory, '%s.xml'%name)
 
@@ -297,8 +323,9 @@ def main():
     try:
       ant_context = main_context(main_file, main_folder)
     except Exception as e:
-      print(e)
+      traceback.print_exc()
       print('Fail to load main_file %s.'%main_file)
+      return
   else:
     ant_context = Context()
   
@@ -318,12 +345,15 @@ def main():
                     'ip': FLAGS.host_ip(),
                     'port': FLAGS.host_port(),
                     'devices': FLAGS.devices(),
-                    'running_platform': FLAGS.running_platform()},
+                    'running_platform': FLAGS.running_platform(),
+                    'unlabel': FLAGS.unlabel(),
+                    'candidate': FLAGS.candidate()},
         })
         ant_context.params = params
     except Exception as e:
-      print(e)
+      traceback.print_exc()
       print('Fail to load main_param %s.'%main_param)
+      return
 
   ant_context.name = name
   ant_context.data_factory = data_factory
@@ -342,7 +372,7 @@ def main():
 
     if not os.path.exists(experiment_path):
       logger.error('Couldnt find experiment %s.'%FLAGS.from_experiment())
-      exit(-1)
+      return
 
     # 设置实验目录
     ant_context.from_experiment = experiment_path
